==> open-xchange-documents-backend_7.8.2.orig.tar.bz2: open-xchange-documents-backend-7.8.2/com.openexchange.office.ooxml/src/com/openexchange/office/ooxml/drawingml/GroupShape.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.ooxml.drawingml;

import org.docx4j.dml.CTGroupShapeProperties;
import org.docx4j.dml.CTGroupTransform2D;
import org.docx4j.dml.IGroupShape;
import org.docx4j.jaxb.Context;
import org.docx4j.openpackaging.exceptions.InvalidFormatException;
import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.office.ooxml.OperationDocument;

public class GroupShape {

	public static void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs, IGroupShape group)
		throws JSONException, InvalidFormatException, PartUnrecognisedException {

        DMLHelper.applyNonVisualDrawingProperties(group, attrs.optJSONObject("drawing"));
        DMLHelper.applyNonVisualDrawingShapeProperties(group, attrs.optJSONObject("drawing"));
	    CTGroupShapeProperties groupProperties = group.getGrpSpPr();
		if(groupProperties==null) {
			groupProperties = Context.getDmlObjectFactory().createCTGroupShapeProperties();
			group.setGrpSpPr(groupProperties);
		}
		DMLHelper.applyTransform2DFromJson(groupProperties, attrs);
		DMLHelper.applyFillPropertiesFromJson(groupProperties, attrs, null, null);
	}

    public static void createJSONAttrs(OperationDocument operationDocument, JSONObject attrs, IGroupShape groupShape)
    	throws JSONException {

        DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, groupShape);
        DMLHelper.createJsonFromNonVisualDrawingShapeProperties(attrs, groupShape);

        final CTGroupShapeProperties groupProperties = groupShape.getGrpSpPr();
		if(groupProperties!=null) {
	        final CTGroupTransform2D groupTransform =groupProperties.getXfrm(false);
	        if(groupTransform!=null) {
	        	DMLHelper.createJsonFromTransform2D(attrs, groupTransform);
	        }
		}
    }
}

==> open-xchange-documents-backend_7.8.3.orig.tar.bz2: open-xchange-documents-backend-7.8.3/com.openexchange.office.ooxml/src/com/openexchange/office/ooxml/drawingml/GroupShape.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.ooxml.drawingml;

import org.docx4j.dml.CTGroupShapeProperties;
import org.docx4j.dml.CTGroupTransform2D;
import org.docx4j.dml.IGroupShape;
import org.docx4j.jaxb.Context;
import org.docx4j.openpackaging.exceptions.InvalidFormatException;
import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.office.ooxml.OperationDocument;

public class GroupShape {

	public static void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs, IGroupShape group, boolean rootShape)
		throws JSONException, InvalidFormatException, PartUnrecognisedException {

        DMLHelper.applyNonVisualDrawingProperties(group, attrs.optJSONObject("drawing"));
        DMLHelper.applyNonVisualDrawingShapeProperties(group, attrs.optJSONObject("drawing"));
	    CTGroupShapeProperties groupProperties = group.getGrpSpPr();
		if(groupProperties==null) {
			groupProperties = Context.getDmlObjectFactory().createCTGroupShapeProperties();
			group.setGrpSpPr(groupProperties);
		}
		DMLHelper.applyTransform2DFromJson(groupProperties, attrs, rootShape);
		DMLHelper.applyFillPropertiesFromJson(groupProperties, attrs, null, null);
	}

    public static void createJSONAttrs(OperationDocument operationDocument, JSONObject attrs, IGroupShape groupShape, boolean rootShape)
    	throws JSONException {

        DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, groupShape);
        DMLHelper.createJsonFromNonVisualDrawingShapeProperties(attrs, groupShape);

        final CTGroupShapeProperties groupProperties = groupShape.getGrpSpPr();
		if(groupProperties!=null) {
	        final CTGroupTransform2D groupTransform =groupProperties.getXfrm(false);
	        if(groupTransform!=null) {
	        	DMLHelper.createJsonFromTransform2D(attrs, groupTransform, rootShape);
	        }
		}
    }
}
